[If you want to check python file of main code go to Bitcoin_Price->BitcoinPrice]
Steps for Setup:
    1. If you do not have python 3 version in your system then, you should update or install it first.
        Go to this link https://www.python.org/downloads/
    2. If you do not have pip installed in your system, you should install it.
        For windows-https://stackoverflow.com/questions/4750806/how-to-install-pip-on-windows
        For Linux-https://www.tecmint.com/install-pip-in-linux/
    3. If system satisfy both requirements than just use following command to install project.
        pip install Bitcoin_Price
    4. If everything installed right than you just have to go to your command prompt or bash and type
        Bitcoin_Price h
        This will show you all commands.
    else do this
        1. Install requirments library, by following command.
            pip install requests.
        2. Download this directory in your system by git clone and pull command.
        3. Open dir and go in Bitcoin_Price->BitcoinPrice, here you can see Bitcoin_Price.py file.
        4. Save the above path as system path by going as
            System properties->Advance system setting->Environmental Variables
            Here left click on path and then left click on Edit.
            Then save the path.
            You can follow this link: https://www.youtube.com/watch?v=Y2q_b4ugPWk for window
                                    https://www.youtube.com/watch?v=abN6bvyPRxQ for linux
        4. After succesfully adding path, open your command prompt or bash and run "Bitcoin_Price.py h, this will shows you all commands"
